"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultAccountSchema = {
    token: {
        type: 'object',
        fieldNumber: 2,
        properties: {
            balance: {
                fieldNumber: 1,
                dataType: 'uint64',
            },
        },
        default: {
            balance: BigInt(0),
        },
    },
    sequence: {
        type: 'object',
        fieldNumber: 3,
        properties: {
            nonce: {
                fieldNumber: 1,
                dataType: 'uint64',
            },
        },
        default: {
            nonce: BigInt(0),
        },
    },
    keys: {
        type: 'object',
        fieldNumber: 4,
        properties: {
            numberOfSignatures: { dataType: 'uint32', fieldNumber: 1 },
            mandatoryKeys: {
                type: 'array',
                items: { dataType: 'bytes' },
                fieldNumber: 2,
            },
            optionalKeys: {
                type: 'array',
                items: { dataType: 'bytes' },
                fieldNumber: 3,
            },
        },
        default: {
            numberOfSignatures: 0,
            mandatoryKeys: [],
            optionalKeys: [],
        },
    },
    dpos: {
        type: 'object',
        fieldNumber: 5,
        properties: {
            delegate: {
                type: 'object',
                fieldNumber: 1,
                properties: {
                    username: { dataType: 'string', fieldNumber: 1 },
                    pomHeights: {
                        type: 'array',
                        items: { dataType: 'uint32' },
                        fieldNumber: 2,
                    },
                    consecutiveMissedBlocks: { dataType: 'uint32', fieldNumber: 3 },
                    lastForgedHeight: { dataType: 'uint32', fieldNumber: 4 },
                    isBanned: { dataType: 'boolean', fieldNumber: 5 },
                    totalVotesReceived: { dataType: 'uint64', fieldNumber: 6 },
                },
                required: [
                    'username',
                    'pomHeights',
                    'consecutiveMissedBlocks',
                    'lastForgedHeight',
                    'isBanned',
                    'totalVotesReceived',
                ],
            },
            sentVotes: {
                type: 'array',
                fieldNumber: 2,
                items: {
                    type: 'object',
                    properties: {
                        delegateAddress: {
                            dataType: 'bytes',
                            fieldNumber: 1,
                        },
                        amount: {
                            dataType: 'uint64',
                            fieldNumber: 2,
                        },
                    },
                    required: ['delegateAddress', 'amount'],
                },
            },
            unlocking: {
                type: 'array',
                fieldNumber: 3,
                items: {
                    type: 'object',
                    properties: {
                        delegateAddress: {
                            dataType: 'bytes',
                            fieldNumber: 1,
                        },
                        amount: {
                            dataType: 'uint64',
                            fieldNumber: 2,
                        },
                        unvoteHeight: {
                            dataType: 'uint32',
                            fieldNumber: 3,
                        },
                    },
                    required: ['delegateAddress', 'amount', 'unvoteHeight'],
                },
            },
        },
        default: {
            delegate: {
                username: '',
                pomHeights: [],
                consecutiveMissedBlocks: 0,
                lastForgedHeight: 0,
                isBanned: false,
                totalVotesReceived: BigInt(0),
            },
            sentVotes: [],
            unlocking: [],
        },
    },
};
//# sourceMappingURL=schema.js.map